summaryrefslogtreecommitdiffstats
path: root/kmail/util.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/util.h')
-rw-r--r--kmail/util.h66
1 files changed, 33 insertions, 33 deletions
diff --git a/kmail/util.h b/kmail/util.h
index 05eb9084..e961bb52 100644
--- a/kmail/util.h
+++ b/kmail/util.h
@@ -40,8 +40,8 @@
#include <stdlib.h>
-#include <qobject.h>
-#include <qcstring.h>
+#include <tqobject.h>
+#include <tqcstring.h>
#include <kio/netaccess.h>
#include <kmessagebox.h>
@@ -74,40 +74,40 @@ namespace Util {
* @param src The source string to convert.
* @return The result string.
*/
- QCString lf2crlf( const QCString & src );
+ TQCString lf2crlf( const TQCString & src );
/**
* Convert "\n" line endings to "\r\n".
* @param src The source string to convert. NOT null-terminated.
* @return The result string. NOT null-terminated.
*/
- QByteArray lf2crlf( const QByteArray & src );
+ TQByteArray lf2crlf( const TQByteArray & src );
/**
* Construct a QCString from a DwString
*/
- QCString CString( const DwString& str );
+ TQCString CString( const DwString& str );
/**
* Construct a QByteArray from a DwString
*/
- QByteArray ByteArray( const DwString& str );
+ TQByteArray ByteArray( const DwString& str );
/**
* Construct a DwString from a QCString
*/
- DwString dwString( const QCString& str );
+ DwString dwString( const TQCString& str );
/**
* Construct a DwString from a QByteArray
*/
- DwString dwString( const QByteArray& str );
+ DwString dwString( const TQByteArray& str );
/**
* Fills a QByteArray from a QCString - removing the trailing null.
*/
- void setFromQCString( QByteArray& arr, const QCString& cstr );
+ void setFromQCString( TQByteArray& arr, const TQCString& cstr );
- inline void setFromQCString( QByteArray& arr, const QCString& cstr )
+ inline void setFromQCString( TQByteArray& arr, const TQCString& cstr )
{
if ( cstr.size() )
arr.duplicate( cstr.data(), cstr.size()-1 );
@@ -116,35 +116,35 @@ namespace Util {
}
/**
* Creates a QByteArray from a QCString without detaching (duplicating the data).
* Fast, but be careful, the QCString gets modified by this; this is only good for
* the case where the QCString is going to be thrown away afterwards anyway.
*/
- QByteArray byteArrayFromQCStringNoDetach( QCString& cstr );
- inline QByteArray byteArrayFromQCStringNoDetach( QCString& cstr )
+ TQByteArray byteArrayFromQCStringNoDetach( TQCString& cstr );
+ inline TQByteArray byteArrayFromQCStringNoDetach( TQCString& cstr )
{
- QByteArray arr = cstr;
+ TQByteArray arr = cstr;
if ( arr.size() )
arr.resize( arr.size() - 1 );
return arr;
}
/**
- * Restore the QCString after byteArrayFromQCStringNoDetach modified it
+ * Restore the TQCString after byteArrayFromQCStringNoDetach modified it
*/
- void restoreQCString( QCString& str );
- inline void restoreQCString( QCString& str )
+ void restoreQCString( TQCString& str );
+ inline void restoreQCString( TQCString& str )
{
if ( str.data() )
str.resize( str.size() + 1 );
}
/**
* Fills a QCString from a QByteArray - adding the trailing null.
*/
- void setFromByteArray( QCString& cstr, const QByteArray& arr );
+ void setFromByteArray( TQCString& cstr, const TQByteArray& arr );
- inline void setFromByteArray( QCString& result, const QByteArray& arr )
+ inline void setFromByteArray( TQCString& result, const TQByteArray& arr )
{
const int len = arr.size();
result.resize( len + 1 /* trailing NUL */ );
@@ -155,19 +155,19 @@ namespace Util {
/**
* Append a bytearray to a bytearray. No trailing nuls anywhere.
*/
- void append( QByteArray& that, const QByteArray& str );
+ void append( TQByteArray& that, const TQByteArray& str );
/**
* Append a char* to a bytearray. Trailing nul not copied.
*/
- void append( QByteArray& that, const char* str );
+ void append( TQByteArray& that, const char* str );
/**
* Append a QCString to a bytearray. Trailing nul not copied.
*/
- void append( QByteArray& that, const QCString& str );
+ void append( TQByteArray& that, const TQCString& str );
- void insert( QByteArray& that, uint index, const char* s );
+ void insert( TQByteArray& that, uint index, const char* s );
/**
* A LaterDeleter is intended to be used with the RAII ( Resource
@@ -179,7 +179,7 @@ namespace Util {
class LaterDeleter
{
public:
- LaterDeleter( QObject *o)
+ LaterDeleter( TQObject *o)
:m_object( o ), m_disabled( false )
{
}
@@ -194,12 +194,12 @@ namespace Util {
m_disabled = v;
}
protected:
- QObject *m_object;
+ TQObject *m_object;
bool m_disabled;
};
// return true if we should proceed, false if we should abort
- inline bool checkOverwrite( const KURL& url, QWidget* w )
+ inline bool checkOverwrite( const KURL& url, TQWidget* w )
{
if ( KIO::NetAccess::exists( url, false /*dest*/, w ) ) {
if ( KMessageBox::Cancel ==
@@ -74,40 +74,40 @@ namespace Util {
/**
- * Construct a QCString from a DwString
+ * Construct a TQCString from a DwString
*/
@@ -74,40 +74,40 @@ namespace Util {
/**
- * Construct a QByteArray from a DwString
+ * Construct a TQByteArray from a DwString
*/
@@ -74,40 +74,40 @@ namespace Util {
/**
- * Fills a QByteArray from a QCString - removing the trailing null.
+ * Fills a TQByteArray from a TQCString - removing the trailing null.
*/
@@ -116,35 +116,35 @@ namespace Util {
}
/**
- * Creates a QByteArray from a QCString without detaching (duplicating the data).
- * Fast, but be careful, the QCString gets modified by this; this is only good for
- * the case where the QCString is going to be thrown away afterwards anyway.
+ * Creates a TQByteArray from a TQCString without detaching (duplicating the data).
+ * Fast, but be careful, the TQCString gets modified by this; this is only good for
+ * the case where the TQCString is going to be thrown away afterwards anyway.
*/
@@ -116,35 +116,35 @@ namespace Util {
}
/**
- * Fills a QCString from a QByteArray - adding the trailing null.
+ * Fills a TQCString from a TQByteArray - adding the trailing null.
*/
@@ -155,19 +155,19 @@ namespace Util {
/**
- * Append a QCString to a bytearray. Trailing nul not copied.
+ * Append a TQCString to a bytearray. Trailing nul not copied.
*/